#
# spec file for package cdogs-sdl
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cdogs-sdl
Version:        1.5.0
Release:        1.4
Summary:        Classic overhead run-and-gun game
License:        BSD-2-Clause AND GPL-2.0-only AND CC-BY-3.0 AND CC-BY-SA-3.0
Group:          Amusements/Games/Action/Shoot
URL:            https://cxong.github.io/cdogs-sdl
Source:         https://github.com/cxong/cdogs-sdl/archive/%{version}/%{name}-%{version}.tar.gz
Source1:        cdogs-sdl.rpmlintrc
Patch0:         fix-build.patch
# PATCH-FIX-UPSTREAM fix-source-file-directory.patch -- https://github.com/cxong/cdogs-sdl/issues/729
#Patch1:         fix-source-file-directory.patch
Patch1:         fix-env-script-interpreter.patch
BuildRequires:  cmake >= 3.12
BuildRequires:  enet-devel
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  python3-protobuf
BuildRequires:  python3-setuptools
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(SDL2_image)
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(physfs)
BuildRequires:  pkgconfig(protobuf)
BuildRequires:  pkgconfig(sdl2)

%description
C-Dogs SDL is a classic overhead run-and-gun game, supporting up to
4 players in co-op and deathmatch modes. Customize your player, choose
from up to 11 weapons, and try over 100 user-created campaigns. Have fun!

%prep
%autosetup -p1
# use system enet
rm -rf src/cdogs/enet

%build
%cmake \
    -DCDOGS_BIN_DIR=%{_bindir}/ \
    -DCDOGS_DATA_DIR=%{_datadir}/%{name}/ \
    -DUSE_SHARED_ENET=ON
%cmake_build

%install
%cmake_install
rm %{buildroot}%{_datadir}/cdogs-sdl/README.md
%fdupes %{buildroot}%{_datadir}
find %{buildroot}%{_datadir}/cdogs-sdl/ -name '*.sh' | xargs chmod a+x

%check
%ctest

%files
%license COPYING
%doc README.md
%{_datadir}/applications/*.desktop
%{_bindir}/%{name}*
%{_datadir}/%{name}/
%{_datadir}/icons/hicolor/*/apps/*.png
%{_datadir}/metainfo/*.appdata.xml

%changelog
* Thu Nov  9 2023 Dirk Müller <dmueller@suse.com>
- update to 1.5.0:
  * Customize hats, hair, facial hair and glasses, plus many bug
    fixes
  * Remove quick play
  * Fix weapons being picked up into incorrect slots
  * Fix grenades not persisting across levels
  * Fix bullets not falling
  * Fix unable to start game with co-op AI, stuck in weapon menu
  * Fix or replace many files with missing or problematic
    licenses (@reinerh)
  * Fix duplicate brass shells
  * Fix poison grenade icon
  * Fix incorrect zapper spritesheet
  * Fix missing music error message
  * Improve character customization by separating hats, hair,
    facial hair and glasses
  * Improve controls info by renaming button1/button2 to
    fire/switch
* Tue May 23 2023 Carsten Ziepke <kieltux@gmail.com>
- update to 1.4.2:
  * Fix crashes when bullets are missing hitsounds
  * Fix not being able to exit vehicles
  * Fix config path to adhere to XDG spec
  * Add buy/sell lives and max health
  * Add upgradable weapons
  * Improve collect objectives by allowing multiple pickup types
  * Editor: Fix crash when copying missions with objectives
* Fri Apr  7 2023 Dirk Müller <dmueller@suse.com>
- update to 1.4.1:
  * Fix weapon swapping with None in equip menu 5281ac6
  * Fix game loading mission via command line 5281ac6
  * Add shareware WOLF3D in main game ad32ed8 (i.e. no need to
    download separately via mission pack)
  * Add buy/sell weapons and ammo functionality #739 (feature
    hidden in WIP techdemo)
  * Add a chainsaw switch sound d99a199
  * Improve actor item drops by making them instant #752
  * Fix crash when duplicating character with no hair b31663b
  * Fix available weapons menu in campaigns with custom weapons
* Tue Dec 13 2022 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 1.4.0
  * Fix Spear of Destiny compatibility with steam Wolfenstein 3D
  * Improve several campaigns with auto-melee weapons (Doom, Wolf3D+SoD)
- Update to version 1.3.1
  * Persistent lives, fix gas bomb poison lasting forever
- Update to version 1.3.0
  * Fix missing controls in editor, and some animation effects and sounds
- Add fix-env-script-interpreter.patch
- Add cdogs-sdl.rpmlintrc to filter out warning on hidden data directory
- Remove fix-source-file-directory.patch
* Fri Dec  3 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.2.0
  * Fix Spear of Destiny secret level warps
  * Fix Spear of Destiny missing wall definition
  * Editor: Fix setting key required for doors
- Add fix-source-file-directory.patch
* Wed Oct 13 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.1.1
  * Support Spear of Destiny mission packs and enhanced wolf3d
    mod support
  Game
  * Remove mouse as game input device, better support for mouse
    in menus #713
  * Add support for Spear of Destiny mission packs
  * Add enemy types being able to see all directions (wolf3d bosses)
  * Add enemy types being able to open locked doors (wolf3d bosses)
  * Fix holowall support for wolf3d mods
  Editor
  * Improve map preview by showing pickups obscured by walls
* Sat Sep 11 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.1.0
  * Show times in end screens
* Sun Sep  5 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.2
  * Fixes for custom Wolf3D campaigns.
* Sat Aug 28 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.1
  * Add support for detecting Linux steam installation of
    Wolf3D/SoD.
* Thu Aug 26 2021 Martin Hauke <mardnh@gmx.de>
- Fix deletion of duplicate README.md
* Sat Aug 21 2021 Martin Hauke <mardnh@gmx.de>
- Update to 1.0.0
  * Support for Wolfenstein 3D and Spear of Destiny
  Game
  * Add support for vehicles #30
  * Add support for multi-guns
  * Add support for custom wreck objects and bullets (allows
    respawning actors on death)
  * Add support for custom actor death animation
  * Add option to skip debrief menu
  * Fix game freeze when returning to game after leaving it paused
    for a while
  * Fix duplicate missions in level select
  * Improve performance by adding max particle limit
  * Improve level select menu with max items limit
  * Improve game start menu by disabling continue option after
    campaign complete
  Editor
  * Fix loading a campaign with less missions showing a blank
    mission #670
  * Add per-mission option to persist weapons (can reset weapons
    on certain missions)
  * Change map shortcut key to tab
- Add patch:
  * fix-build.patch
* Tue Jul 20 2021 Martin Hauke <mardnh@gmx.de>
- Update to 0.13.0
  Game
  * Add weapon sprites
  * Add molotov glass break sound
  * Add AI waking to gunfire
  * Add AI peripheral vision
  * Add AI wake on seeing teammate under attack
  * Fix feet colors for classic campaigns
  * Fix sliding diagonally against map objects and getting stuck
  * Fix player not getting poisoned
  * Fix AI not waking when seeing player
  * Fix co-op AI not shooting
  * Fix missing bullet hole marks
  * Fix minor typo in campaign
  * Improve save file with saved weapons and ammo
  * Improve save file, saves individual missions completed
  * Improve gun dropping, limit gun drops after 2 are present
  * Improve ammo dropped by enemies by halving amount
  * Improve character previews by showing gun
  * Improve weapon selection screen with character rotation
  * Improve text particles by drawing above everything
  * Improve pulse animation by doubling its frequency
  Editor
  * Add character deafness flag
  * Add custom character item drops
  * Add separate bullet flesh/object hit properties (bullets can
    hit actors but not map objects)
  * Fix loading classic campaigns via drag-drop
  * Fix tooltip for immunity flag
  * Improve character previews by showing gun
- Remove patch:
  * fix-multiple-definitions.patch
* Sat May 22 2021 Martin Hauke <mardnh@gmx.de>
- Update to 0.12.0
  Game
  * Fix LAN bugs
  * Fix crash if laser sight is enabled
  * Fix crash in AI Insurgency II campaign
  * Add dual-wielded pistols
  * Add pistol and chaingun gun models
  * Add score text popup on collecting score pickups
  * Improve AI by waking immediately on being hit
  * Improve AI by not reacting immediately on wake
  * Improve changing volume options by not rewinding music
  Editor / Modding
  * Fix "HitsObjects": false behavior for bullets, should not
    damage map objects if set
  * Add highlights to walk-through walls
  * Add customizable door auto-close delay in campaign options
  * Add ability to set character direction in static map type
  * Add customizable special damage duration in bullets.json
  * Add customizable corpse map object in character_classes.json
  * Change map object placement to allow them to be placed over
    ones with 0 health (e.g. wrecks, blood pools)
* Thu Apr 29 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 0.11.1
  * Add building interior map generator
  * Add mouse controls for menus
  * Add fists weapon
  * Add custom footstep sounds for bones character class
  * Add auto-play --demo mode
  * Add live backgrounds
  * Add pigtails hair
  * Fix crash when changing options
  * Fix score popups not updating position
  * Fix friendly fire from status-inducing weapons e.g. poison
  * Fix flower not dropping pickups
  * Fix frequent hangs at game startup, interior map generator
  * Fix alert sounds for invisible characters
  * Fix donut hair
  * Improve options menus with left/right arrows
  * Change menu sounds
  * Change hitsounds enabled on invulnerable characters
  * Editor:
  * Add some new tile types and map objects e.g. cobble wall
  * Add ability to place map objects of different types
    on same tile
  * Add random door position option for classic/interior
    map types
  * Add collapse UI area via grave key
  * Fix flood fill crashing when applied at map edge
  * Fix non-solid map objects added repeatedly at same position
- Add fix-multiple-definitions.patch
* Tue Jan  5 2021 Martin Hauke <mardnh@gmx.de>
- Update to 0.10.2:
  * Fix loading classic campaigns
  * Fix PVP rounds not ending
  * Fix missing mouse cursor and trail
  * Fix linux build
  * Fix dogfight scores not updated properly
  * Add peaked cap hat
  * Add soldier body type
  * Improve weapon equip menu, show available weapons, allow gun
    swapping.
  * Improve game startup by skipping mission briefing if it is empty
- Drop not longer neede patches
  * cdogs-sdl-fix-desktop-and-appdata.patch
  * nanopb.patch
- Package license file and readme
* Tue Dec  1 2020 Martin Hauke <mardnh@gmx.de>
- Update to 0.10.1:
  * Fix freeze when slow moving bullets wall bounce.
* Fri Nov 27 2020 Martin Hauke <mardnh@gmx.de>
- Update to 0.10.0:
  * Fix weapon pickup issues.
  * Fix various trailer and hitscan issues.
  * Fix crash when saving new player template.
  * Fix black "(End)" menu item in player name menu.
  * Fix bullet trail color.
  * Fix crash when co-op AI present in mission with show map
    pickup.
  * Add dog character.
  * Add option for missions having no exit area.
  * Add multiple body types in various campaigns.
  * Add facial expressions when using melee weapon, getting hurt.
* Thu Oct  1 2020 Martin Hauke <mardnh@gmx.de>
- Update to 0.9.1:
  * Fix bugs that spawn player in locked rooms
  Game
  * Fix spawning player in locked rooms.
  * Fix spawning keys inside locked doors.
  * Add show map powerup in Doom campaign.
  Editor
  * Add color highlights for locked rooms.
  Other
  * Fix linker issue in gcc10 (fixed by @susnux).
- Drop patch:
  * cdogs-gLog.patch (fixed upstream)
* Wed Sep 30 2020 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 0.9.0:
  * Feature complete Doom campaign
  Game
  * Add feet colors
  * Add new hairs/hats: helmet, donut, hazmat
  * Add AI wake sounds #651
  * Fix sound spam at start of maps #605
  * Improve weapon selection by disabling menus if there are none available #628
  * Improve pause menu with background overlay #283
  Editor
  * Add level warp, multiple exits #451
  * Add static pickups #644
  * Add player template editing in editor #495
  * Add option to skip weapon selection screen #647
  * Add option for keeping picked up guns across missions #573
  * Add option for ammo persistence #350
  * Fix numpad insert/delete in editor #353
- Added nanopb.patch from nanopb upstream
- Added cdogs-gLog.patch to fix build with new gcc
- Rebased cdogs-sdl-fix-desktop-and-appdata.patch
- Spec cleanup
* Mon May 25 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.8.0
  * Custom tile classes and revamped Doom campaign
  Game
  * Fix string overflow for long weapon descriptions
  * Fix players sometimes spawning in locked rooms
  * Fix missing death animation
  * Fix leg animation when stationary shooting
  * Fix some bullet colors
  * Add button labels for PS3/PS4 controllers
  * Improve Doom campaign with multiple tile types, walk-through
    walls
  Editor
  * Fix background clearing
  * Add support for custom tile types for static maps
  * Add hair editing in char editor
  * Add native file open/save dialogs
  * Add support for drag/dropping guide image
  * Add hardware cursors
  * Improve guide image rendering speed
* Sun Jan  5 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.7.3
  Editor
  * Fix previews in character editor
  * Fix crash when changing colors
  * Add crosshairs when drag-scrolling
- Update patch:
  * cdogs-sdl-fix-desktop-and-appdata.patch
* Sat Dec 21 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.7.2
  Fix editor
  * Remove broken second window option
  * Fix editor
  * Fix mission end scores infinite incrementing
  * Fix bullet hole rendering on doors
  * Add fullscreen switching via Alt+Enter shortcut
- Add patch:
  * cdogs-sdl-fix-desktop-and-appdata.patch
* Sat Nov 23 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.7.1
  * Fix quickplay campaigns being auto saved
  * Fix broken animated score counter in debrief if score was
    negative
  * Fix red doors drawn as grey doors
  * Fix ammo count drawn under ammo gauge
  * Fix gun pickups visible even when out of sigh
  * Fix spall particles excessive speed when hit by fast bullets
  * Fix enemies dropping detonator weapon in AI Insurgency II
  * Fix NPC chatter visible even when out of sight
  * Fix NPC chatter frequency config
  * Fix NPC chatter visible in menu backgrounds
  * Fix map drawn outside automap area
  * Improve sprites with palette recoloring
* Fri Nov  1 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.7.0
  Release highlights since 0.6.7:
  * New GUI and Special Effects
  * Hitscan trails and Superhot(tm) mode
  * Full screen fixes and gun swapping
- Drop not longer needed patch:
  * cdogs-sdl-buildfix.patch
* Mon Jun 18 2018 mardnh@gmx.de
- Update to version 0.6.7
  * Add secondary weapon system (#33)
  * Add diagonal direction stickiness (#457)
  * Add option to remove blood (#544)
  * Fix unpausing not ignoring first key press (#548)
  * Fix compass arrows in shared camera view (#530)
  * Improve some sprites with semi-transparency
- Add patch:
  * cdogs-sdl-buildfix.patch
* Thu Nov  2 2017 mailaender@opensuse.org
- update to version 0.6.6 (New campaigns and HUD improvements)
  * New campaign, Grave Intent
  * New campaign, AI Insurgency 2
  * Update Sand campaign, new weapons
  * Update Doom campaign, new map items
  * Fix AI line-of-sight algorithm (#227)
  * Fix logging colours in Linux (#523)
  * Fix blood splatter speed (#489)
  * Fix audio panning (#507)
  * Fix recording high scores for co-op AI (#386)
  * Fix loading static wrecks in some older campaigns
  * Add new character heads - evil ogre, bones, big bones
  * Add second window (#383)
  * Add floating text for pickups (#380)
  * Add low ammo notifications (#362)
  * Add QWERTY layout name entry (#517)
  * Improve spectator HUD, show HUD (#382)
  * Improve health gauge, add animations (#360)
  * Improve co-op AI by avoiding friendly lines of fire (#295)
  * Fix copy pasting static levels (#525)
  * Fix incorrect objective counts when adding static objectives (#527)
  * Fix rescue/kill objectives not using access flags
  * Improve cave map type, add rooms, squares
- drop system-enet.patch (included upstream)
* Mon Jun  5 2017 mailaender@opensuse.org
- update to version 0.6.5
  * Add Harmful Crysalis campaign
  * Add hitscan weapons, continuous collision detection (#372)
  * Add scream sounds for females and other races (#371)
  * Add sound effect for opening/closing map (#468)
  * Add random seed to game start options
  * Fix editor crash on startup (#488)
  * Fix destroyed map objects dropping unavailable weapons (#493)
  * Fix missing custom hitsounds
  * Fix console window shown in Windows (#229)
  * Improve character editor (#462)
  * Improve Doom campaign with gun spawners, chainsaw, hitscan weapons
  * Add pickups from destroyed map objects (#367)
  * Add gas leak sound effect
  * Add pitch variations to some sound effects (#369)
  * Add some animated map objects to AI Insurgency campaign
  * Fix mission time not synced over network (#405)
  * Improve walk animation (#18)
  * Change command line option to allow arbitrary config settings (#473)
- drop upstreamed datadir.patch install-prefix.patch copying.patch
- drop cdogs-sdl-0.6.1-mga-unbundle-yajl.patch as lib is customized
- replace cdogs-sdl-0.6.0-mga-unbundle-enet.patch with system-enet.patch
* Fri Nov 18 2016 mailaender@opensuse.org
- update to version 0.6.3
  * Add new character faces (#69)
  * Add new character color keys (#441, #61)
  * Add Temple of Carnage dogfight map
  * Add bullet mass attribute (#444)
  * Add animated map objects (#430)
  * Add option to turn off brass shells (#448)
  * Add highlights for gun pickups
  * Add --nohud
  * Add Splitscreen AI config
  * Add extra logging around gun pickups
  * Fix showing map when paused (#446)
  * Fix various bugs around split screen logic
  * Fix obsolete valid graphics mode check (#449)
  * Fix gun recoil animations
- remove patches applied by upstream
  * cmake-install.patch
  * appdata.patch
- add copying.patch to fix FSF address etc.
- add datadir.patch and install-prefix.patch to fix the installer
* Sat Aug 20 2016 mailaender@opensuse.org
- initial packaging of version 0.6.2
